@@ -12,10 +12,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BINLIBDEST': '/usr/local/lib/python3.7',
  'BLDLIBRARY': '-L. -lpython3.7m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 -L/usr/local/lib/',
+              '-L/build/tmp/pobj//Python-3.7.10/Python-3.7.10 '
+              '-L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'arm-unknown-openbsd6.8',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd6.8',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
@@ -37,7 +38,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
                 "'--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.7.9/Python-3.7.9' "
+                "'--srcdir=/build/tmp/pobj//Python-3.7.10/Python-3.7.10' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
@@ -48,8 +49,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.7.9/Python-3.7.9/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.7.9/Python-3.7.9/lcov-report',
+ 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.7.10/Python-3.7.10/coverage.info',
+ 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.7.10/Python-3.7.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -95,7 +96,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -203,7 +204,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -490,29 +491,29 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'arm-unknown-openbsd6.8',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.8',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.7m '
                    '/usr/local/include/python3.7m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.7m',
- 'INSTALL': '/usr/obj/ports/Python-3.7.9/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.7.9/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 555',
+ 'INSTALL': '/build/tmp/pobj//Python-3.7.10/bin/install -c',
+ 'INSTALL_DATA': '/build/tmp/pobj//Python-3.7.10/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.7.10/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.7.10/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.7.10/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.7m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
+ 'LDFLAGS': '-L/usr/local/lib/ -L/build/tmp/pobj//Python-3.7.10/Python-3.7.10 '
             '-L/usr/local/lib/',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 -L/usr/local/lib/',
+             '-L/build/tmp/pobj//Python-3.7.10/Python-3.7.10 -L/usr/local/lib/',
  'LDVERSION': '3.7m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.7',
@@ -536,7 +537,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LLVM_PROF_MERGER': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
- 'LOG1P_DROPS_ZERO_SIGN': 0,
+ 'LOG1P_DROPS_ZERO_SIGN': 1,
  'MACHDEP': 'openbsd6',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/local/lib/python3.7',
@@ -631,11 +632,12 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
-                    '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
+                    '-L/build/tmp/pobj//Python-3.7.10/Python-3.7.10 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
+ 'PY_LDFLAGS': '-L/usr/local/lib/ '
+               '-L/build/tmp/pobj//Python-3.7.10/Python-3.7.10 '
                '-L/usr/local/lib/',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -654,7 +656,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.7.10/Python-3.7.10',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -668,7 +670,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -696,10 +698,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.7.10/Python-3.7.10 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.7.10/Python-3.7.10 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -719,10 +721,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.7.9/Python-3.7.9',
- 'abs_srcdir': '/usr/obj/ports/Python-3.7.9/Python-3.7.9',
+ 'abs_builddir': '/build/tmp/pobj/Python-3.7.10/Python-3.7.10',
+ 'abs_srcdir': '/build/tmp/pobj/Python-3.7.10/Python-3.7.10',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
